@@ -144,6 +144,7 @@ ArkWidget::ArkWidget( QWidget *parent, const char *name )
 
     // enable DnD
     setAcceptDrops(true);
+    setFocusProxy(m_searchBar);
 }
 
 ArkWidget::~ArkWidget()
@@ -493,13 +494,6 @@ ArkWidget::extractToSlotOpenDone( bool success )
     bool keepGoing = true;
     if ( !ArkSettings::extractOverwrite() && !alreadyExisting.isEmpty() )
     {
-       if ( alreadyExisting.count() == m_nNumFiles )
-        {
-            KMessageBox::error( this, i18n( "None of the files in the archive have been\n"
-                                            "extracted since all of them already exist.") );
-            emit request_file_quit();
-            return;
-        }
         keepGoing = ( KMessageBox::Continue == KMessageBox::warningContinueCancelList( this,
                     i18n( "The following files will not be extracted\nbecause they "
                           "already exist:" ), alreadyExisting ) );
@@ -1305,40 +1299,43 @@ void
 ArkWidget::slotOpenWith()
 {
     connect( arch, SIGNAL( sigExtract( bool ) ), this,
-            SLOT( openWithSlotExtractDone() ) );
+            SLOT( openWithSlotExtractDone( bool ) ) );
 
     showCurrentFile();
 }
 
 void
-ArkWidget::openWithSlotExtractDone()
+ArkWidget::openWithSlotExtractDone( bool success )
 {
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this,
-            SLOT( openWithSlotExtractDone() ) );
+            SLOT( openWithSlotExtractDone( bool ) ) );
 
-    KURL::List list;
-    list.append(m_viewURL);
-    KOpenWithDlg l( list, i18n("Open with:"), QString::null, (QWidget*)0L);
-    if ( l.exec() )
+    if ( success )
     {
-        KService::Ptr service = l.service();
-        if ( !!service )
-        {
-            KRun::run( *service, list );
-        }
-        else
-        {
-            QString exec = l.text();
-            exec += " %f";
-            KRun::run( exec, list );
-        }
+      KURL::List list;
+      list.append(m_viewURL);
+      KOpenWithDlg l( list, i18n("Open with:"), QString::null, (QWidget*)0L);
+      if ( l.exec() )
+      {
+          KService::Ptr service = l.service();
+          if ( !!service )
+          {
+              KRun::run( *service, list );
+          }
+          else
+          {
+              QString exec = l.text();
+              exec += " %f";
+              KRun::run( exec, list );
+          }
+      }
     }
+
     if( m_fileListView )
     {
         m_fileListView->setUpdatesEnabled(true);
         fixEnables();
     }
-
 }
 
 
@@ -1375,17 +1372,11 @@ ArkWidget::reportExtractFailures( const QString & _dest, QStringList *_list )
 
     // now report on the contents
     holdBusy();
-    if (numFilesToReport == 1)
+    if (numFilesToReport != 0)
     {
-        kdDebug(1601) << "One to report" << endl;
-        strFilename = filesExisting.first();
-        QString message = i18n("%1 will not be extracted because it will overwrite an existing file.\nGo back to the Extraction Dialog?").arg(strFilename);
-        redoExtraction = (KMessageBox::questionYesNo(this, message) == KMessageBox::Yes);
-    }
-    else if (numFilesToReport != 0)
-    {
-        QString message = i18n("Some files will not be extracted, because they would overwrite existing files.\nWould you like to go back to the extraction dialog?\n\nThe following files will not be extracted if you choose to continue:");
-        redoExtraction = (KMessageBox::questionYesNoList(this, message, filesExisting) == KMessageBox::Yes);
+        redoExtraction =  ( KMessageBox::Cancel == KMessageBox::warningContinueCancelList( this,
+                    i18n( "The following files will not be extracted\nbecause they "
+                          "already exist:" ), filesExisting ) );
     }
     resumeBusy();
     return redoExtraction;
@@ -1415,7 +1406,9 @@ ArkWidget::existingFiles( const QString & _dest, QStringList & _list )
     {
         strFilename = *it;
         QString strFullName = strDestDir + strFilename;
-        if ( QFile::exists( strFullName ) )
+
+        // if the filename ends with an "/", it means it is a directory
+        if ( QFile::exists( strFullName ) && !strFilename.endsWith("/") )
         {
             existingFiles.append( strFilename );
         }
