@@ -60,7 +60,16 @@
                 #include <math.h>
         #endif
 
-int isinf(double x) { return !finite(x) && x==x; }
+#undef isinf
+int isinf(double x) 
+{
+#ifdef _HPUX_SOURCE
+return !isfinite(x) && x == x;
+#else
+return !finite(x) && x==x; 
+#endif
+}
+
 #endif
 
 
@@ -449,7 +458,7 @@ void CalcEngine::Complement(KNumber input)
 		_last_number = KNumber("nan");
 		return;
 	}
-	_last_number =  ExecXor(KNumber(0xffffffff), input);
+	_last_number = - input - KNumber::One; 
 }
 
 
