@@ -20,8 +20,6 @@
 #ifndef _KNUMBER_H
 #define _KNUMBER_H
 
-#include <gmp.h>
-
 #include <kdelibs_export.h>
 
 #include "knumber_priv.h"
@@ -70,6 +68,7 @@ class KDE_EXPORT KNumber
   static KNumber const MinusOne;
   static KNumber const Pi;
   static KNumber const Euler;
+  static KNumber const NotDefined;
 
   /**
    * KNumber tries to provide transparent access to the following type
@@ -105,9 +104,12 @@ class KDE_EXPORT KNumber
    *
    */
   enum ErrorType {UndefinedNumber, Infinity, MinusInfinity};
-  
-  KNumber(signed int num = 1);
-  KNumber(unsigned int num);
+
+  KNumber(signed int num = 0);
+  KNumber(unsigned int num);  
+  KNumber(signed long int num);
+  KNumber(unsigned long int num);
+  KNumber(unsigned long long int num);
 
   KNumber(double num);
 
@@ -240,7 +242,9 @@ class KDE_EXPORT KNumber
   KNumber const operator>>(KNumber const & arg2) const;
 
   operator bool(void) const;
-  operator long int(void) const;
+  operator signed long int(void) const;
+  operator unsigned long int(void) const;
+  operator unsigned long long int(void) const;
   operator double(void) const;
 
   bool const operator==(KNumber const & arg2) const
