@@ -42,6 +42,23 @@ _knumerror::_knumerror(_knumber const & num)
   }
 }
 
+
+
+_knuminteger::_knuminteger(unsigned long long int num)
+{
+  mpz_init(_mpz);
+#if SIZEOF_UNSIGNED_LONG == 8
+  mpz_init_set_ui(_mpz, static_cast<unsigned long int>(num));
+#elif SIZEOF_UNSIGNED_LONG == 4
+  mpz_set_ui(_mpz, static_cast<unsigned long int>(num >> 32));
+  mpz_mul_2exp(_mpz, _mpz, 32);
+  mpz_add_ui(_mpz, _mpz, static_cast<unsigned long int>(num));
+#else
+#error "SIZEOF_UNSIGNED_LONG is a unhandled case"
+#endif 
+}
+
+
 _knuminteger::_knuminteger(_knumber const & num)
 {
   mpz_init(_mpz);
