@@ -329,6 +329,13 @@ void ButtonsConfig::save()
 
 void ButtonsConfig::load()
 {
+	load( false );
+}
+
+void ButtonsConfig::load(bool useDefaults)
+{
+  config->setReadDefaults( useDefaults );
+
   config->setGroup("LaptopButtons");
   lid = config->readNumEntry("LidSuspend", 0);
   power = config->readNumEntry("PowerSuspend", 0);
@@ -407,7 +414,7 @@ void ButtonsConfig::load()
 		powerValThrottle->setCurrentItem(ind);
 		powerValThrottle->setEnabled(power_throttle_enabled);
 	}
-  changed(false);
+  emit changed( useDefaults );
 }
 
 void ButtonsConfig::defaults()
