@@ -408,14 +408,20 @@ void WarningConfig::save()
 
 void WarningConfig::load()
 {
-	if (config == NULL)
-		return;
-	my_load(0);
-	my_load(1);
+	load( false );
 }
 
-void WarningConfig::my_load(int x)
+void WarningConfig::load(bool useDefaults)
 {
+	if (config == NULL)
+		return;
+	my_load(0, useDefaults);
+	my_load(1, useDefaults);
+}
+
+void WarningConfig::my_load(int x, bool useDefaults )
+{
+	config->setReadDefaults( useDefaults );
 
 	// open the config file
 	if (!x) {
@@ -522,86 +528,12 @@ void WarningConfig::my_load(int x)
                 
                 editPlaySound->setURL(sound_val);
 	}
-	changed(false);
-
+	emit changed(useDefaults);
 }
 
 void WarningConfig::defaults()
 {
-	// open the config file
-	runcommand = false;
-	playsound = false;
-	beep = true;
-	logout = false;
-	shutdown = false;
-	notify = !(type && checkSuspend);
-	do_standby = false;
-	do_hibernate = false;
-	do_brightness = 1;
-	val_brightness = (type?0:160);
-	do_performance = 0;
-	val_performance = "";
-	do_throttle = 0;
-	val_throttle = "";
-	do_suspend = (type && checkSuspend);
-	runcommand_val = "";
-        time_based_action_low = true;
-        time_based_action_critical = true;
-        low_val_time = 15;
-        low_val_percent = 7;
-        critical_val_time = 5;
-        critical_val_percent = 3;
-        sound_val = "";
-
-	if (apm) {
-		checkRunCommand->setChecked(runcommand);
-		checkPlaySound->setChecked(playsound);
-		checkBeep->setChecked(beep);
-		if (checkBrightness)
-			checkBrightness->setChecked(do_brightness);
-		if (valueBrightness) {
-			valueBrightness->setValue(val_brightness);
-  			valueBrightness->setEnabled(do_brightness);
-		}
-		if (performance)
-			performance->setChecked(do_performance);
-		if (performance_val) {
-			performance_val->setCurrentItem(0);
-  			performance_val->setEnabled(do_performance);
-		}
-		if (throttle)
-			throttle->setChecked(do_throttle);
-		if (throttle_val) {
-			throttle_val->setCurrentItem(0);
-  			throttle_val->setEnabled(do_throttle);
-		}
-		checkLogout->setChecked(logout);
-		checkNotify->setChecked(notify);
-		checkShutdown->setChecked(shutdown);
-		if (checkHibernate) {
-			checkHibernate->setChecked(do_hibernate);
-		} else {
-			do_hibernate = 0;
-		}
-		if (checkStandby) {
-			checkStandby->setChecked(do_standby);
-		} else {
-			do_standby = 0;
-		}
-		if (checkSuspend) {
-			checkSuspend->setChecked(do_suspend);
-		} else {
-			do_suspend = 0;
-		}
-		checkNone->setChecked(!do_suspend&!do_standby&!do_hibernate&!logout&!shutdown);
-		editRunCommand->setURL(runcommand_val);
-		editLowTime->setValue(low_val_time);
-                editLowPercent->setValue(low_val_percent);
-                editCriticalTime->setValue(critical_val_time);
-                editCriticalPercent->setValue(critical_val_percent);
-		editPlaySound->setURL(sound_val);
-	}
-	changed(true);
+	load( true );
 }
 
 
