@@ -12,11 +12,11 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
-#ifndef __characterswidget
-#define __characterswidget
+#ifndef characterswidget
+#define characterswidget
 
 #ifdef QT_ONLY
 #include "compat.h"
@@ -26,15 +26,13 @@
 
 #include <kmultiformlistbox.h>
 #include "regexpwidget.h"
-#include "limitedcharlineedit.h"
-#include <qhbox.h>
-#include <qcheckbox.h>
 #include <qvgroupbox.h>
 
 class KDialogBase;
 class CharacterEdits;
 class TextRangeRegExp;
 class CharSelector;
+class QCheckBox;
 
 /**
    RegExp widget for charcter ranges.
@@ -143,4 +141,4 @@ private:
     TextRangeRegExp* _regexp;
 };
 
-#endif // __characterswidget
+#endif // characterswidget
