@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <kapplication.h>
@@ -23,10 +23,10 @@
 
 #include "ktimer.h"
 
-static const char *description =
+static const char description[] =
         I18N_NOOP("KDE Timer");
 
-static const char *version = "v0.1";
+static const char version[] = "v0.1";
 
 int main( int argc, char **argv )
 {
